@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
-our $DATE = '2019-11-28'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-Sah-Schemas'; # DIST
+our $VERSION = '0.017'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,20 +91,10 @@ sub munge_files {
         my $sch = ${"$pkg\::schema"} or do {
             $self->log_fatal(["No schema defined in \$schema in %s", $file->name]);
         };
+        # actually we don't have to normalize manually, we require the schemas
+        # to be normalized anyway. but to be safer.
         my $nsch = Data::Sah::Normalize::normalize_schema($sch);
 
-        # check that schema is already normalized
-        {
-            require Data::Dump;
-            require Data::Sah::Normalize;
-            require Text::Diff;
-            my $sch_dmp  = Data::Dump::dump($sch);
-            my $nsch_dmp = Data::Dump::dump($nsch);
-            last if $sch_dmp eq $nsch_dmp;
-            my $diff = Text::Diff::diff(\$sch_dmp, \$nsch_dmp);
-            $self->log_fatal(["Schema in %s is not normalized, below is the dump diff (- is current, + is normalized): %s", $file->name, $diff]);
-        }
-
         # collect other Sah::Schema::* modules that are used, this will
         # be added as prereq
       COLLECT_BASE_SCHEMAS:
@@ -218,8 +210,33 @@ sub munge_files {
 }
 
 sub gather_files {
-    # we add files in the munge_files() phase because at this point,
-    # found_files() doesn't yet work
+    my ($self) = @_;
+
+  SAH_SCHEMA_T: {
+        my $filename = "xt/release/sah-schema.t";
+        my $filecontent = <<'_';
+#!perl
+
+# This file was automatically generated by Dist::Zilla::Plugin::Sah::Schemas.
+
+use Test::More;
+
+eval "use Test::Sah::Schema 0.001";
+plan skip_all => "Test::Sah::Schema 0.001 required for testing Sah::Schema::* modules"
+  if $@;
+
+sah_schema_modules_ok();
+_
+
+        $self->log(["Adding %s ...", $filename]);
+        require Dist::Zilla::File::InMemory;
+        $self->add_file(
+            Dist::Zilla::File::InMemory->new({
+                name => $filename,
+                content => $filecontent,
+            })
+          );
+    }
 }
 
 sub register_prereqs {
@@ -228,6 +245,15 @@ sub register_prereqs {
 
     my $self = shift;
 
+    # add DevelopRequires to module required by xt/release/sah-schema.t
+    $self->zilla->register_prereqs(
+        {
+            type  => 'requires',
+            phase => 'develop',
+        },
+        'Test::Sah::Schema' => '0',
+    );
+
     # add prereqs to base schema modules
 
     for my $mod (sort keys %{$self->{_used_schema_modules} // {}}) {
@@ -281,7 +307,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.016 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2019-11-28.
+This document describes version 0.017 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2020-03-02.
 
 =head1 SYNOPSIS
 
@@ -291,8 +317,19 @@ In F<dist.ini>:
 
 =head1 DESCRIPTION
 
-This plugin is to be used when building C<Sah-Schemas-*> distribution. It
-currently does the following to C<lib/Sah/Schemas/*> .pm files:
+This plugin is to be used when building C<Sah-Schemas-*> distribution.
+
+It adds F<xt/release/sah-schema.t> which does the following:
+
+=over
+
+=item * Check that schema is already normalized
+
+=item * Test examples in schema
+
+=back
+
+It does the following to every C<lib/Sah/Schemas/*> .pm file:
 
 =over
 
@@ -300,14 +337,10 @@ currently does the following to C<lib/Sah/Schemas/*> .pm files:
 
 =back
 
-It does the following to C<lib/Sah/Schema/*> .pm files:
+It does the following to every C<lib/Sah/Schema/*> .pm file:
 
 =over
 
-=item * Check that schema is already normalized
-
-Otherwise, the build is aborted.
-
 =item * Set module abstract from the schema's summary
 
 =item * Add a prereq to other Sah::Schema::* module if schema depends on those other schemas
@@ -352,7 +385,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
